@@ -1363,8 +1363,7 @@ class Origin(AbstractModel):
 
     def __init__(self):
         """
-        :param Origins: 主源站列表，默认格式为 ["ip1:port1", "ip2:port2"]。
-支持在源站列表中配置权重，配置IP源站权重格式为 ["ip1:port1:weight1", "ip2:port2:weight2"]。
+        :param Origins: 主源站列表，IP与域名源站不可混填。配置源站端口["origin1:port1", "origin2:port2"]，配置回源权重["origin1::weight1", "origin2::weight2"]，同时配置端口与权重 ["origin1:port1:weight1", "origin2:port2:weight2"]，权重值有效范围为0-100。
         :type Origins: list of str
         :param OriginType: 主源站类型，支持domain，ip，分别表示域名源站，ip源站。
 设置Origins时必须填写。
@@ -1374,6 +1373,7 @@ class Origin(AbstractModel):
 注意：此字段可能返回 null，表示取不到有效值。
         :type ServerName: str
         :param OriginPullProtocol: 回源协议类型，支持http，follow，https，分别表示强制http回源，协议跟随回源，https回源。
+不传入的情况下默认为http回源.
 注意：此字段可能返回 null，表示取不到有效值。
         :type OriginPullProtocol: str
         :param BackupOrigins: 备份源站列表。
